@@ -314,7 +314,7 @@ class VersionedObject(object):
                                   field.stringify(getattr(self, name)) or
                                   '<?>'))
                       for name, field in sorted(self.fields.items())]))
-        if not six.PY3:
+        if six.PY2:
             repr_str = encodeutils.safe_encode(repr_str, incoming='utf-8')
         return repr_str
 
@@ -706,6 +706,9 @@ class ComparableVersionedObject(object):
             return self.obj_to_primitive() == obj.obj_to_primitive()
         return NotImplemented
 
+    def __hash__(self):
+        return super(ComparableVersionedObject, self).__hash__()
+
     def __ne__(self, obj):
         if hasattr(obj, 'obj_to_primitive'):
             return self.obj_to_primitive() != obj.obj_to_primitive()
@@ -1129,7 +1132,7 @@ def obj_tree_get_versions(objname, tree=None):
     level object with other objects as fields. It walks the tree recursively
     to determine all the objects (by symbolic name) that could be contained
     within the top-level object, and the maximum versions of each. The result
-    is a dict like:
+    is a dict like::
 
       {'MyObject': '1.23', ... }
 
