@@ -26,7 +26,7 @@ from oslo_utils import strutils
 from oslo_utils import timeutils
 import six
 
-from oslo_versionedobjects._i18n import _, _LE
+from oslo_versionedobjects._i18n import _
 from oslo_versionedobjects import _utils
 from oslo_versionedobjects import exception
 
@@ -359,7 +359,7 @@ class UUID(StringPattern):
                               "release. Please update your "
                               "code to input valid UUIDs or accept "
                               "ValueErrors for invalid UUIDs. See "
-                              "http://docs.openstack.org/developer/oslo.versionedobjects/api/fields.html#oslo_versionedobjects.fields.UUIDField "  # noqa
+                              "https://docs.openstack.org/oslo.versionedobjects/latest/reference/fields.html#oslo_versionedobjects.fields.UUIDField "  # noqa
                               "for further details" % value, FutureWarning)
 
             return str(value)
@@ -376,7 +376,7 @@ class MACAddress(StringPattern):
             lowered = value.lower().replace('-', ':')
             if MACAddress._REGEX.match(lowered):
                 return lowered
-        raise ValueError(_LE("Malformed MAC %s"), value)
+        raise ValueError(_("Malformed MAC %s") % (value,))
 
 
 class PCIAddress(StringPattern):
@@ -390,7 +390,7 @@ class PCIAddress(StringPattern):
             newvalue = value.lower()
             if PCIAddress._REGEX.match(newvalue):
                 return newvalue
-        raise ValueError(_LE("Malformed PCI address %s"), value)
+        raise ValueError(_("Malformed PCI address %s") % (value,))
 
 
 class Integer(FieldType):
@@ -711,14 +711,14 @@ class DictProxyField(object):
         if getattr(obj, self._fld_name) is None:
             return
         return {self._key_type(k): v
-                for k, v in six.iteritems(getattr(obj, self._fld_name))}
+                for k, v in getattr(obj, self._fld_name).items()}
 
     def __set__(self, obj, val):
         if val is None:
             setattr(obj, self._fld_name, val)
         else:
             setattr(obj, self._fld_name,
-                    {six.text_type(k): v for k, v in six.iteritems(val)})
+                    {six.text_type(k): v for k, v in val.items()})
 
 
 class Set(CompoundFieldType):
@@ -821,7 +821,7 @@ class Object(FieldType):
         else:
             ident = ''
 
-        return '%s%s' % (self._obj_name, ident)
+        return '%s%s' % (value.obj_name(), ident)
 
     def get_schema(self):
         from oslo_versionedobjects import base as obj_base
@@ -838,7 +838,7 @@ class Object(FieldType):
             required_fields = [key for key, field in sorted(cls.fields.items())
                                if not field.nullable]
             schema = {
-                'type': 'object',
+                'type': ['object'],
                 'properties': {
                     namespace_key: {
                         'type': 'string'
@@ -1036,7 +1036,7 @@ class UUIDField(AutoTypedField):
     your own objects/fields.py
 
     :Example:
-         .. code-block:: python
+        .. code-block:: python
 
             import oslo_versionedobjects.fields as ovo_fields
 
@@ -1049,8 +1049,8 @@ class UUIDField(AutoTypedField):
             class UUIDField(ovo_fields.AutoTypedField):
                 AUTO_TYPE = UUID()
 
-        and then in your objects use
-        ``<your_projects>.object.fields.UUIDField``.
+    and then in your objects use
+    ``<your_projects>.object.fields.UUIDField``.
 
     This will become default behaviour in the future.
     """
@@ -1266,7 +1266,7 @@ class CoercedDict(CoercedCollectionMixin, dict):
 
     def _coerce_dict(self, d):
         res = {}
-        for key, element in six.iteritems(d):
+        for key, element in d.items():
             res[key] = self._coerce_item(key, element)
         return res
 
