@@ -1200,6 +1200,20 @@ class _TestObject(object):
         obj2 = MySensitiveObj()
         self.assertEqual('MySensitiveObj(data=<?>)', repr(obj2))
 
+    def test_obj_repr_unicode(self):
+        obj = MyObj(bar=u'\u0191\u01A1\u01A1')
+        # verify the unicode string has been encoded as ASCII if on python 2
+        if six.PY2:
+            self.assertEqual("MyObj(bar='\xc6\x91\xc6\xa1\xc6\xa1',foo=<?>,"
+                             "missing=<?>,mutable_default=<?>,readonly=<?>,"
+                             "rel_object=<?>,rel_objects=<?>,timestamp=<?>)",
+                             repr(obj))
+        else:
+            self.assertEqual("MyObj(bar='\u0191\u01A1\u01A1',foo=<?>,"
+                             "missing=<?>,mutable_default=<?>,readonly=<?>,"
+                             "rel_object=<?>,rel_objects=<?>,timestamp=<?>)",
+                             repr(obj))
+
     def test_obj_make_obj_compatible_with_relationships(self):
         subobj = MyOwnedObject(baz=1)
         obj = MyObj(rel_object=subobj)
@@ -2076,7 +2090,7 @@ class TestSchemaGeneration(test.TestCase):
     class FakeComplexObject(base.VersionedObject):
         fields = {
             'a_dict': fields.DictOfListOfStringsField(),
-            'an_obj': fields.ObjectField('FakeObject'),
+            'an_obj': fields.ObjectField('FakeObject', nullable=True),
             'list_of_objs': fields.ListOfObjectsField('FakeObject'),
         }
 
@@ -2085,7 +2099,7 @@ class TestSchemaGeneration(test.TestCase):
         self.assertEqual({
             '$schema': 'http://json-schema.org/draft-04/schema#',
             'title': 'FakeObject',
-            'type': 'object',
+            'type': ['object'],
             'properties': {
                 'versioned_object.namespace': {
                     'type': 'string'
@@ -2159,7 +2173,7 @@ class TestSchemaGeneration(test.TestCase):
                                              'versioned_object.name',
                                              'versioned_object.version',
                                              'versioned_object.data'],
-                                'type': 'object'},
+                                'type': ['object', 'null']},
                         'list_of_objs': {
                             'items': {
                                 'properties': {
@@ -2184,10 +2198,10 @@ class TestSchemaGeneration(test.TestCase):
                                              'versioned_object.name',
                                              'versioned_object.version',
                                              'versioned_object.data'],
-                                'type': 'object'},
+                                'type': ['object']},
                             'readonly': False,
                             'type': ['array']}},
-                    'required': ['a_dict', 'an_obj', 'list_of_objs'],
+                    'required': ['a_dict', 'list_of_objs'],
                     'type': 'object'},
                 'versioned_object.name': {'type': 'string'},
                 'versioned_object.namespace': {'type': 'string'},
@@ -2197,7 +2211,7 @@ class TestSchemaGeneration(test.TestCase):
                          'versioned_object.version',
                          'versioned_object.data'],
             'title': 'FakeComplexObject',
-            'type': 'object'}
+            'type': ['object']}
         self.assertEqual(expected_schema, schema)
 
         fake_obj = self.FakeComplexObject(
